@@ -30,7 +30,7 @@ static QString intPairListToString(const QVariant &var)
         if (!ret.isEmpty()) {
             ret += ' ';
         }
-        ret += QString::number(pair.first) + "," + QString::number(pair.second);
+        ret += QString::number(pair.first) + ',' + QString::number(pair.second);
     }
     return ret;
 }
@@ -46,7 +46,7 @@ JobTrackerTest::~JobTrackerTest()
 
 void JobTrackerTest::initTestCase()
 {
-    // Don't interfer with a running akonadiconsole
+    // Don't interfere with a running akonadiconsole
     Akonadi::Instance::setIdentifier("jobtrackertest");
 
     qRegisterMetaType<QList<QPair<int, int>>>();
