@@ -23,7 +23,6 @@
 #include "ui_agentconfigdialog.h"
 #include <AkonadiCore/AgentInstance>
 #include <QDialog>
-#include <KConfigGroup>
 
 class AgentConfigModel;
 
@@ -39,7 +38,7 @@ private Q_SLOTS:
 
 private:
     Ui::AgentConfigDialog ui;
-    AgentConfigModel *m_model;
+    AgentConfigModel *m_model = nullptr;
     Akonadi::AgentInstance m_instance;
 };
 
