@@ -34,11 +34,8 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KStandardGuiItem>
-#include <KTextEdit>
-#include <QLineEdit>
 #include <QIcon>
 
-#include <QFile>
 #include <QPointer>
 #include <QMenu>
 #include <QPushButton>
@@ -49,7 +46,6 @@
 #include <QResizeEvent>
 #include <KGuiItem>
 #include <QDialogButtonBox>
-#include <KConfigGroup>
 #include <QVBoxLayout>
 
 class TextDialog : public QDialog
@@ -58,18 +54,19 @@ public:
     explicit TextDialog(QWidget *parent = nullptr)
         : QDialog(parent)
     {
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
         QVBoxLayout *mainLayout = new QVBoxLayout(this);
+        mText = new KPIMTextEdit::PlainTextEditorWidget(this);
+        mText->setReadOnly(true);
+
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok, this);
         QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
         okButton->setDefault(true);
         okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
         connect(buttonBox, &QDialogButtonBox::accepted, this, &TextDialog::accept);
         connect(buttonBox, &QDialogButtonBox::rejected, this, &TextDialog::reject);
 
-        mText = new KPIMTextEdit::PlainTextEditorWidget;
         mainLayout->addWidget(mText);
         mainLayout->addWidget(buttonBox);
-        mText->setReadOnly(true);
         resize(QSize(400, 600));
     }
 
@@ -79,7 +76,7 @@ public:
     }
 
 private:
-    KPIMTextEdit::PlainTextEditorWidget *mText;
+    KPIMTextEdit::PlainTextEditorWidget *mText = nullptr;
 };
 
 using namespace Akonadi;
