@@ -19,8 +19,6 @@
 
 #include "notificationmodel.h"
 
-#include <QCoreApplication>
-#include <QBuffer>
 
 #include <QLocale>
 
@@ -48,7 +46,7 @@ public:
 
     virtual QVariant data(int column) const = 0;
 
-    NotificationModel::Item *parent;
+    NotificationModel::Item *parent = nullptr;
     QVector<Item *> nodes;
     int type;
 };
@@ -505,9 +503,10 @@ void NotificationModel::slotNotify(const Akonadi::ChangeNotification &ntf)
 
 void NotificationModel::clear()
 {
+    beginResetModel();
     qDeleteAll(m_data);
     m_data.clear();
-    reset();
+    endResetModel();
 }
 
 Protocol::ChangeNotificationPtr NotificationModel::notification(const QModelIndex &index) const
