@@ -23,34 +23,28 @@
 #include "ui_queryviewdialog.h"
 #include "storagedebuggerinterface.h"
 
-#include <QMenu>
-#include <QGuiApplication>
 
 #include <QAbstractListModel>
 #include <QSortFilterProxyModel>
 #include <QHeaderView>
 #include <QDateTime>
-#include <QIcon>
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QTableWidget>
 #include <QFileDialog>
 
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusArgument>
-#include <QtDBus/QDBusMetaType>
+#include <QDBusConnection>
+#include <QDBusArgument>
 
 #include <AkonadiCore/servermanager.h>
 #include <AkonadiWidgets/controlgui.h>
 
-#include <KLocalizedString>
 #include <KColorScheme>
 
 #include <algorithm>
 
 Q_DECLARE_METATYPE(QList< QList<QVariant> >)
 
-
 QDBusArgument &operator<<(QDBusArgument &arg, const DbConnection &con)
 {
     arg.beginStructure();
@@ -267,9 +261,9 @@ public:
         query->results = results;
         query->error = error.trimmed();
 
-        if (!con->queries.isEmpty()
-            && con->queries.last()->type == Transaction
-            && static_cast<TransactionNode*>(con->queries.last())->transactionType == TransactionNode::Begin) {
+        if (!con->queries.isEmpty() &&
+            con->queries.last()->type == Transaction &&
+            static_cast<TransactionNode*>(con->queries.last())->transactionType == TransactionNode::Begin) {
             auto trx = static_cast<TransactionNode*>(con->queries.last());
             query->parent = trx;
             beginInsertRows(createIndex(con->queries.indexOf(trx), 0, trx),
@@ -527,7 +521,6 @@ private:
     QHash<qint64, ConnectionNode *> mConnectionById;
 };
 
-
 class QueryDebuggerModel : public QAbstractListModel
 {
     Q_OBJECT
@@ -544,7 +537,7 @@ public:
         TOTAL,
         NUM_SPECIAL_ROWS
     };
-    enum Colums {
+    enum COLUMNS {
         DurationColumn,
         CallsColumn,
         AvgDurationColumn,
@@ -586,9 +579,8 @@ public:
             return QVariant();
         }
 
-        const QueryInfo &info = (row < NUM_SPECIAL_ROWS)
-                                ? mSpecialRows[row]
-                                : mQueries.at(row - NUM_SPECIAL_ROWS);
+        const QueryInfo &info =
+            (row < NUM_SPECIAL_ROWS) ? mSpecialRows[row] : mQueries.at(row - NUM_SPECIAL_ROWS);
 
         if (role == Qt::ToolTipRole) {
             return QString(QLatin1String("<qt>") + info.query + QLatin1String("</qt>"));
@@ -665,7 +657,6 @@ private:
     QueryInfo mSpecialRows[NUM_SPECIAL_ROWS];
 };
 
-
 class QueryViewDialog : public QDialog
 {
     Q_OBJECT
@@ -711,7 +702,6 @@ public:
 
         connect(mUi->buttonBox, &QDialogButtonBox::rejected,
                 this, &QDialog::accept);
-
     }
 
 private:
@@ -745,10 +735,10 @@ QueryDebugger::QueryDebugger(QWidget *parent):
     proxy->setSourceModel(mQueryList);
     proxy->setDynamicSortFilter(true);
     mUi->queryListView->setModel(proxy);
-    mUi->queryListView->header()->setResizeMode(QueryDebuggerModel::CallsColumn, QHeaderView::Fixed);
-    mUi->queryListView->header()->setResizeMode(QueryDebuggerModel::DurationColumn, QHeaderView::Fixed);
-    mUi->queryListView->header()->setResizeMode(QueryDebuggerModel::AvgDurationColumn, QHeaderView::Fixed);
-    mUi->queryListView->header()->setResizeMode(QueryDebuggerModel::QueryColumn, QHeaderView::ResizeToContents);
+    mUi->queryListView->header()->setSectionResizeMode(QueryDebuggerModel::CallsColumn, QHeaderView::Fixed);
+    mUi->queryListView->header()->setSectionResizeMode(QueryDebuggerModel::DurationColumn, QHeaderView::Fixed);
+    mUi->queryListView->header()->setSectionResizeMode(QueryDebuggerModel::AvgDurationColumn, QHeaderView::Fixed);
+    mUi->queryListView->header()->setSectionResizeMode(QueryDebuggerModel::QueryColumn, QHeaderView::ResizeToContents);
 
     connect(mUi->queryTreeView, &QTreeView::doubleClicked,
             this, &QueryDebugger::queryTreeDoubleClicked);
@@ -808,8 +798,8 @@ void QueryDebugger::addQuery(double sequence, qint64 connectionId, qint64 timest
 
 void QueryDebugger::queryTreeDoubleClicked(const QModelIndex &index)
 {
-    if (static_cast<QueryTreeModel::RowType>(index.data(QueryTreeModel::RowTypeRole).toInt())
-            != QueryTreeModel::Query) {
+    if (static_cast<QueryTreeModel::RowType>(index.data(QueryTreeModel::RowTypeRole).toInt()) !=
+        QueryTreeModel::Query) {
         return;
     }
 
@@ -840,5 +830,4 @@ void QueryDebugger::saveTreeToFile()
     file.close();
 }
 
-
 #include "querydebugger.moc"
