@@ -23,9 +23,8 @@
 
 #include <AkonadiCore/AttributeFactory>
 #include <QSqlQuery>
-#include <QSqlError>
-#include <KConfigGroup>
 #include <QDialogButtonBox>
+#include <QSqlError>
 
 using namespace Akonadi;
 
@@ -60,7 +59,7 @@ bool TagPropertiesDialog::changed() const
 
 void TagPropertiesDialog::setupUi()
 {
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
